@@ -1,9 +1,9 @@
 from datetime import datetime
 from typing import Generic, Optional, Type
 
-from databases import Database
 from fastapi_users.authentication.strategy.db import A, AccessTokenDatabase
-from sqlalchemy import Column, DateTime, ForeignKey, String, Table
+from sqlalchemy import Column, DateTime, ForeignKey, String, delete, select, update
+from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.ext.declarative import declared_attr
 
 from fastapi_users_db_sqlalchemy.guid import GUID
@@ -27,45 +27,52 @@ class SQLAlchemyAccessTokenDatabase(AccessTokenDatabase, Generic[A]):
     Access token database adapter for SQLAlchemy.
 
     :param access_token_model: Pydantic model of a DB representation of an access token.
-    :param database: `Database` instance from `encode/databases`.
-    :param access_tokens: SQLAlchemy access token table instance.
+    :param session: SQLAlchemy session instance.
+    :param access_token_table: SQLAlchemy access token model.
     """
 
     def __init__(
-        self, access_token_model: Type[A], database: Database, access_tokens: Table
+        self,
+        access_token_model: Type[A],
+        session: AsyncSession,
+        access_token_table: SQLAlchemyBaseAccessTokenTable,
     ):
         self.access_token_model = access_token_model
-        self.database = database
-        self.access_tokens = access_tokens
+        self.session = session
+        self.access_token_table = access_token_table
 
     async def get_by_token(
         self, token: str, max_age: Optional[datetime] = None
     ) -> Optional[A]:
-        query = self.access_tokens.select().where(self.access_tokens.c.token == token)
+        statement = select(self.access_token_table).where(
+            self.access_token_table.token == token
+        )
         if max_age is not None:
-            query = query.where(self.access_tokens.c.created_at >= max_age)
+            statement = statement.where(self.access_token_table.created_at >= max_age)
 
-        access_token = await self.database.fetch_one(query)
-        if access_token is not None:
-            return self.access_token_model(**access_token)
-        return None
+        results = await self.session.execute(statement)
+        access_token = results.first()
+        if access_token is None:
+            return None
+        return self.access_token_model.from_orm(access_token[0])
 
     async def create(self, access_token: A) -> A:
-        query = self.access_tokens.insert()
-        await self.database.execute(query, access_token.dict())
+        access_token_db = self.access_token_table(**access_token.dict())
+        self.session.add(access_token_db)
+        await self.session.commit()
         return access_token
 
     async def update(self, access_token: A) -> A:
-        update_query = (
-            self.access_tokens.update()
-            .where(self.access_tokens.c.token == access_token.token)
+        statement = (
+            update(self.access_token_table)
+            .where(self.access_token_table.token == access_token.token)
             .values(access_token.dict())
         )
-        await self.database.execute(update_query)
+        await self.session.execute(statement)
         return access_token
 
     async def delete(self, access_token: A) -> None:
-        query = self.access_tokens.delete().where(
-            self.access_tokens.c.token == access_token.token
+        statement = delete(
+            self.access_token_table, self.access_token_table.token == access_token.token
         )
-        await self.database.execute(query)
+        await self.session.execute(statement)
